@@ -33,6 +33,7 @@
 #include "mini-commander_applet.h"
 
 static void reset_temporary_prefs(void);
+static void phelp_cb (void);
 
 static gboolean
 pattern_entry_changed_signal(GtkWidget *entry_widget, GdkEventFocus *event, gpointer data)
@@ -267,6 +268,7 @@ load_session(MCData *mcdata)
     GConfValue *macro_patterns, *macro_commands;
     GSList *pattern_list = NULL, *command_list = NULL;
     properties *prop;
+    GError *error = NULL;
     int i;
     char section[MAX_COMMAND_LENGTH + 100];
     char default_macro_pattern[MAX_MACRO_PATTERN_LENGTH];
@@ -278,7 +280,12 @@ load_session(MCData *mcdata)
     prop->show_date = FALSE;
     prop->show_default_theme = panel_applet_gconf_get_bool (applet, 
                                       			    "show_default_theme", 
-                                      		  	    NULL);
+                                      		  	    &error);
+    if (error) {
+	g_print ("%s \n", error->message);
+	g_error_free (error);
+	error = NULL;
+    }
     prop->show_handle = panel_applet_gconf_get_bool (applet, "show_handle", NULL);
     prop->show_frame = panel_applet_gconf_get_bool(applet, "show_frame", NULL);
 
@@ -288,7 +295,9 @@ load_session(MCData *mcdata)
 
     /* size */
     prop->normal_size_x = panel_applet_gconf_get_int(applet, "normal_size_x", NULL);
+    prop->normal_size_x = CLAMP (prop->normal_size_x, 50, 200);
     prop->normal_size_y = panel_applet_gconf_get_int(applet, "normal_size_y", NULL);
+    prop->normal_size_y = CLAMP (prop->normal_size_y, 5, 200);
     prop->reduced_size_x = 50;
     prop->reduced_size_y = 48;
     prop->cmd_line_size_y = 24;
@@ -489,13 +498,16 @@ load_session(MCData *mcdata)
 }
 
 static void
-phelp_cb (GtkWidget *w, gint tab, gpointer data)
+phelp_cb (void)
 {
-   #if 0 /* FIXME */
-        GnomeHelpMenuEntry help_entry = { "mini-commander_applet",
-                                          "index.html#MINI-COMMANDER-PREFS" };
-        gnome_help_display(NULL, &help_entry);
-   #endif
+    GError *error = NULL;
+    gnome_help_display ("command-line", "command-line-prefs-0", &error);
+
+    if (error) {
+        g_warning ("help error: %s\n", error->message);
+        g_error_free (error);
+        error = NULL;
+    }
 }
 
 static void
@@ -647,6 +659,11 @@ static void
 response_cb (GtkDialog *dialog, gint it, gpointer data)
 {
     MCData *mcdata = data;
+
+    if(it == GTK_RESPONSE_HELP){
+        phelp_cb ();
+        return;
+    }
     
     gtk_widget_destroy (GTK_WIDGET (dialog));
     mcdata->properties_box = NULL;
@@ -686,6 +703,7 @@ properties_box(BonoboUIComponent *uic, gpointer data, const gchar *verbname)
     						  NULL,
 						  GTK_DIALOG_DESTROY_WITH_PARENT,
 						  GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+						  GTK_STOCK_HELP, GTK_RESPONSE_HELP,
 						  NULL);
     gtk_dialog_set_default_response (GTK_DIALOG (mcdata->properties_box), GTK_RESPONSE_CLOSE);
     gtk_window_set_default_size (GTK_WINDOW (mcdata->properties_box), 400, 300);
@@ -873,7 +891,7 @@ properties_box(BonoboUIComponent *uic, gpointer data, const gchar *verbname)
     gtk_container_add(GTK_CONTAINER(frame), table);
 
     /* default bg and fg theme */
-    check_theme = gtk_check_button_new_with_mnemonic("_Use default theme colors");
+    check_theme = gtk_check_button_new_with_mnemonic(_("_Use default theme colors"));
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_theme), prop->show_default_theme);
     g_signal_connect (G_OBJECT (check_theme), "toggled",
     		      G_CALLBACK (check_theme_toggled), mcdata); 
