@@ -35,6 +35,10 @@ void
 about_cb (BonoboUIComponent *uic, gpointer data, const gchar *name)
 {
     static GtkWidget *about = NULL;
+    GdkPixbuf        *pixbuf;
+    GError           *error = NULL;
+    gchar            *file;
+   
     static const gchar *authors[] =
 	{
 		"Martin Baulig <martin@home-of-linux.org>",
@@ -42,6 +46,13 @@ about_cb (BonoboUIComponent *uic, gpointer data, const gchar *name)
 		NULL
 	};
 
+    const gchar *documenters[] =
+	{
+		NULL
+	};
+
+    const gchar *translator_credits = _("translator_credits");
+
     if (about != NULL)
 	{
 	    gdk_window_show(about->window);
@@ -49,16 +60,31 @@ about_cb (BonoboUIComponent *uic, gpointer data, const gchar *name)
 	    return;
 	}
 	
+    file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gnome-monitor.png", FALSE, NULL);
+    pixbuf = gdk_pixbuf_new_from_file (file, &error);
+    g_free (file);
+   
+    if (error) 
+    	{
+   	    g_warning (G_STRLOC ": cannot open %s: %s", file, error->message);
+	    g_error_free (error);
+   	}
+
+	
     about = gnome_about_new
-	(_("System Monitor Applet"), VERSION,
+	(_("System Monitor"), VERSION,
 	 "(C) 1999 - 2002 The Free Software Foundation",
 	 _("Released under the GNU General Public License.\n\n"
 	   "A system load monitor capable of displaying graphs for CPU, ram, and swap file use, plus network traffic."),
 	 authors,
-	 NULL,
-	 NULL,
-	 NULL);
+	 documenters,
+	 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+	 pixbuf);
 
+    if (pixbuf) 
+   	gdk_pixbuf_unref (pixbuf);
+   
+    gtk_window_set_wmclass (GTK_WINDOW (about), "system monitor", "System Monitor");
     g_signal_connect (G_OBJECT (about), "destroy",
 			G_CALLBACK (gtk_widget_destroyed), &about);
 
@@ -75,32 +101,35 @@ start_procman_cb (BonoboUIComponent *uic, gpointer data, const gchar *name)
 }
               
 void
-multiload_change_size_cb(PanelApplet *applet, gint arg1, gpointer data)
+multiload_change_size_cb(PanelApplet *applet, gint size, gpointer data)
 {
 	gint i;
 	MultiloadApplet *ma = (MultiloadApplet *)data;
 
-	for (i = 0; i < 5; i++)
-		if (ma->graphs[i]->visible)
-		{
-  	  	if (ma->graphs[i]->orient)
-				gtk_widget_set_size_request (ma->graphs[i]->main_widget, ma->graphs[i]->pixel_size, ma->graphs[i]->size);
-			else
-				gtk_widget_set_size_request (ma->graphs[i]->main_widget, ma->graphs[i]->size, ma->graphs[i]->pixel_size);
-		}
-		
+	for (i = 0; i < 5; i++) {
+		ma->graphs[i]->pixel_size = size;
+  	  	if (ma->graphs[i]->orient) 
+  	  		gtk_widget_set_size_request (ma->graphs[i]->main_widget, 
+					             ma->graphs[i]->pixel_size, 
+						     ma->graphs[i]->size);
+		else
+			gtk_widget_set_size_request (ma->graphs[i]->main_widget, 
+							     ma->graphs[i]->size, 
+							     ma->graphs[i]->pixel_size);
+	}
+	
 	return;
 }
 
 void
 multiload_change_orient_cb(PanelApplet *applet, gint arg1, gpointer data)
 {
+	MultiloadApplet *ma = data;
 	multiload_applet_refresh((MultiloadApplet *)data);
-		
+	gtk_widget_show (GTK_WIDGET (ma->applet));		
 	return;
 }
 
-/* FIXME: i'm not sure if this is setup wrong or libpanel is broken.  this doesn't work at all. */
 void
 multiload_destroy_cb(GtkWidget *widget, gpointer data)
 {
@@ -206,7 +235,7 @@ multiload_applet_refresh(MultiloadApplet *ma)
 {
 	gint i;
 	PanelAppletOrient orientation;
-		
+	
 	/* stop and free the old graphs */
 	for (i = 0; i < 5; i++)
 	{
@@ -224,8 +253,10 @@ multiload_applet_refresh(MultiloadApplet *ma)
 	
 	orientation = panel_applet_get_orient(ma->applet);
 	
-	if ( (orientation == PANEL_APPLET_ORIENT_UP) || (orientation == PANEL_APPLET_ORIENT_DOWN) )
-		ma->box = gtk_hbox_new(FALSE, 0);
+	if ( (orientation == PANEL_APPLET_ORIENT_UP) || 
+	     (orientation == PANEL_APPLET_ORIENT_DOWN) ) {
+	     	ma->box = gtk_hbox_new(FALSE, 0);
+	}
 	else
 		ma->box = gtk_vbox_new(FALSE, 0);
 	
@@ -241,15 +272,17 @@ multiload_applet_refresh(MultiloadApplet *ma)
 	
 	/* only start and display the graphs the user has turned on */
 
-	for (i = 0; i < 5; i++)
-		if (ma->graphs[i]->visible)
-		{
-			gtk_box_pack_start(GTK_BOX(ma->box), ma->graphs[i]->main_widget, FALSE, FALSE, 1);
-			load_graph_start(ma->graphs[i]);
-		}
-	
-	gtk_widget_show_all(GTK_WIDGET(ma->applet));
-		
+	for (i = 0; i < 5; i++) {
+	    gtk_box_pack_start(GTK_BOX(ma->box), 
+			       ma->graphs[i]->main_widget, 
+			       FALSE, FALSE, 1);
+	    if (ma->graphs[i]->visible) {
+	    	gtk_widget_show_all (ma->graphs[i]->main_widget);
+		load_graph_start(ma->graphs[i]);
+	    }
+	}
+	gtk_widget_show (ma->box);
+			
 	return;
 }
 
@@ -266,6 +299,8 @@ multiload_applet_new(PanelApplet *applet, const gchar *iid, gpointer data)
 	
 	ma->applet = applet;
 	
+	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-monitor.png");
+	
 	panel_applet_add_preferences (applet, "/schemas/apps/multiload/prefs", NULL);
 	
 	orientation = panel_applet_get_orient(applet);
@@ -285,12 +320,15 @@ multiload_applet_new(PanelApplet *applet, const gchar *iid, gpointer data)
 	ma->graphs[4] = loadavg_applet_new(applet, NULL);
 
 	/* only start and display the graphs the user has turned on */
-	for (i = 0; i < 5; i++)
-		if (ma->graphs[i]->visible)
-		{
-			gtk_box_pack_start(GTK_BOX(box), ma->graphs[i]->main_widget, FALSE, FALSE, 1);
-			load_graph_start(ma->graphs[i]);
-		}
+	for (i = 0; i < 5; i++) {
+	    gtk_box_pack_start(GTK_BOX(box), 
+			       ma->graphs[i]->main_widget, 
+			       FALSE, FALSE, 1);
+	    if (ma->graphs[i]->visible) {
+	    	gtk_widget_show_all (ma->graphs[i]->main_widget);
+		load_graph_start(ma->graphs[i]);
+	    }
+	}
 
 	{
 		/* we need to pass 'ma' into the properties_cb or else every instance of multiload will use the same properties dialog*/
@@ -319,8 +357,11 @@ multiload_applet_new(PanelApplet *applet, const gchar *iid, gpointer data)
 				G_CALLBACK(multiload_destroy_cb), ma);
 	g_signal_connect(G_OBJECT(applet), "enter_notify_event",
 				G_CALLBACK(multiload_enter_cb), ma);
-					
-	gtk_widget_show_all(GTK_WIDGET(applet));
+	multiload_change_size_cb (ma->applet,
+				  panel_applet_get_size (ma->applet),
+				  ma);	
+	gtk_widget_show (box);			
+	gtk_widget_show(GTK_WIDGET(applet));
 			
 	return TRUE;
 }
